Fliq class

The main class for making HTTP requests using the Fliq library.

Example:

final client = Fliq();
final response = await client.get('https://example.com').go();
print('Status Code: ${response.statusCode}');
client.close();

Constructors

Fliq()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the underlying HttpClient.
delete(String url) FliqRequest
Initiates a DELETE request with the specified url.
get(String url) FliqRequest
Initiates a GET request with the specified url.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String url) FliqRequest
Initiates a POST request with the specified url.
put(String url) FliqRequest
Initiates a PUT request with the specified url.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited