FormFile class

Represents a file in a multipart form data request.

Constructors

FormFile(String fieldName, String fileName, List<int> fileBytes)
Constructs a new instance of MultipartFile.

Properties

fieldName String
getter/setter pair
fileBytes List<int>
getter/setter pair
fileName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRequest() List<int>
Converts the file data to a format suitable for a multipart form data request.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited